@@ -1,28 +1,24 @@
 ;;; tlc --- Major mode for editing tlc files -*- lexical-binding: t -*-
 
-;; Copyright (C) 2024 Free Software Foundation, Inc.
-
 ;; Author: Eric M. Ludlam <eludlam@mathworks.com>
 ;; Keywords: tlc
 ;; X-Abstract: Major mode for editing tlc files
 
-(defvar tlc-version "1.3"
-  "The current version of TLC mode.")
-
-;; This program is derived from free software; you can redistribute it
-;; and/or modify it under the terms of the GNU General Public License
-;; as published by the Free Software Foundation; either version 3, or
-;; (at your option) any later version.
+;; Copyright (C) 1998-2024 Free Software Foundation, Inc.
 ;;
-;; This program is distributed in the hope that it will be useful,
+;; This file is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published
+;; by the Free Software Foundation, either version 3 of the License,
+;; or (at your option) any later version.
+;;
+;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 ;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
-;;
+;; along with this file.  If not, see <https://www.gnu.org/licenses/>.
+
 ;;; Commentary:
 ;;
 ;;  This is a major mode for editing Target Language Compiler, TLC, programs.
@@ -109,8 +105,8 @@
 ;;      will have the "2 + ..." and "3" line shown using tlc-font-lock-output-code.
 ;;      To fix, we probably need to use Multiline Font Lock constructs.
 
-;;; History:
-;;
+;; History:
+;; --------
 ;;  10Sep1998 by Eric M.  Ludlam <eludlam@mathworks.com>
 ;;    Posted First revision onto the FTP site.
 ;;
@@ -120,9 +116,13 @@
 ;;    - added autoload cookies.
 ;;    - CVS storage elsewhere without changing the version number.
 ;;
-;;  Recent history is in the ChangeLog and the matlab-emacs repository.
+;;  Recent history is in the repository commits.
 
 ;;; Code:
+
+(defvar tlc-version "1.3"
+  "The current version of TLC mode.")
+
 (defun tlc-version ()
   "Display the current version of TLC mode."
   (interactive)
@@ -137,6 +137,10 @@
   :group 'tlc
   :type 'hook)
 
+(defvar tlc--imenu-generic-expression
+  '((nil "^[ \t]*%function[ \t]+\\([a-zA-Z0-9_]+\\)" 1))
+  "Regexp to find function names in *.tlc files for `imenu'.")
+
 (defvar tlc-syntax-table nil
   "Syntax table used in an TLC file.")
 
@@ -233,21 +237,19 @@
   (setq mode-name "TLC")
   (use-local-map tlc-mode-map)
   (set-syntax-table tlc-syntax-table)
-  (make-local-variable 'comment-start)
-  (make-local-variable 'comment-end)
-  (make-local-variable 'comment-start-skip)
-  (setq comment-start "%% "
-        comment-end   "")
-  (setq comment-start-skip "%%\\|/%")
-  (make-local-variable 'indent-line-function)
-  (setq indent-line-function 'tlc-indent)
-  (make-local-variable 'font-lock-defaults)
-  (setq font-lock-defaults '((tlc-font-lock-keywords)
+  (setq-local comment-start "%% ")
+  (setq-local comment-end   "")
+  (setq-local comment-start-skip "%%\\|/%")
+  (setq-local indent-line-function 'tlc-indent)
+  (setq-local font-lock-defaults '((tlc-font-lock-keywords)
                              nil ; do not do string/comment highlighting
                              nil ; keywords are case sensitive.
                              ;; This puts _ as a word constituent,
                              ;; simplifying our keywords significantly
                              ((?_ . "w"))))
+
+  (setq-local imenu-generic-expression tlc--imenu-generic-expression)
+
   (tlc-version)
   (save-excursion
     (goto-char (point-min))
@@ -504,4 +506,4 @@ EXISTS(\"?\\(?:::\\)?_[A-Z_0-9]+_\"?)\\s-*==\\s-*\\(?:0\\|TLC_FALSE\\)\\|\
 
 ;; LocalWords:  Ludlam eludlam galbraith psg debian defun defcustom setq keymap defface grayscale sw
 ;; LocalWords:  IDNUM NUMTLCFILES STRINGOF SYSNAME TLCFILES UINTWHITE repeat:nil prog calc endswitch
-;; LocalWords:  bobp nexti progn alist el stackexchange ppss openfile closefile curr elsif
+;; LocalWords:  bobp nexti progn alist el stackexchange ppss openfile closefile curr elsif imenu
